@@ -1,3 +1,7 @@
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 #include "CpuInfo.h"
 
 #include <QFile>
@@ -27,6 +31,23 @@ bool CpuInfo::loadCpuInfo()
     // read the file /proc/cpuinfo
     if (!readProcCpuinfo())
         return false;
+
+    // 重新编号
+    QMap<int, PhysicalCpu> curMapPhysicalCpu = m_MapPhysicalCpu;
+    m_MapPhysicalCpu.clear();
+    foreach (int id, curMapPhysicalCpu.keys()) {
+        PhysicalCpu physical = PhysicalCpu(id);
+
+        PhysicalCpu &curPhysical = curMapPhysicalCpu[id];
+        QList<int> curCoreNums = curPhysical.coreNums();
+        for (int i = 0; i < curCoreNums.size(); ++i) {
+            CoreCpu curCoreCpu = curPhysical.coreCpu(curCoreNums[i]);
+            curCoreCpu.setCoreId(i);
+            physical.addCoreCpu(i, curCoreCpu);
+        }
+        m_MapPhysicalCpu.insert(id, physical);
+    }
+
     return true;
 }
 
@@ -138,14 +159,26 @@ bool CpuInfo::parseInfo(const QString &info)
             return false;
         PhysicalCpu &physical = m_MapPhysicalCpu[physical_id];
         int core_id = mapInfo["core id"].toInt();
-        if (!physical.coreIsExisted(core_id))
-            return false;
-        CoreCpu &core = physical.coreCpu(core_id);
-        if (!core.logicalIsExisted(logical_id))
-            return false;
-        LogicalCpu &logical = core.logicalCpu(logical_id);
-        if (logical.logicalID() >= 0)
-            setProcCpuinfo(logical, mapInfo);
+        if (!physical.coreIsExisted(core_id)) {
+            if (physical.logicalIsExisted(logical_id)) {
+                LogicalCpu &logical = physical.logicalCpu(logical_id);
+                if (logical.logicalID() >= 0)
+                    setProcCpuinfo(logical, mapInfo);
+            }
+        } else {
+            CoreCpu &core = physical.coreCpu(core_id);
+            if (!core.logicalIsExisted(logical_id)) {
+                if (physical.logicalIsExisted(logical_id)) {
+                    LogicalCpu &logical = physical.logicalCpu(logical_id);
+                    if (logical.logicalID() >= 0)
+                        setProcCpuinfo(logical, mapInfo);
+                }
+            } else {
+                LogicalCpu &logical = core.logicalCpu(logical_id);
+                if (logical.logicalID() >= 0)
+                    setProcCpuinfo(logical, mapInfo);
+            }
+        }
     } else {
         LogicalCpu &logical = logicalCpu(logical_id);
         if (logical.logicalID() >= 0)
@@ -158,9 +191,9 @@ bool CpuInfo::parseInfo(const QString &info)
 LogicalCpu &CpuInfo::logicalCpu(int logical_id)
 {
     foreach (int physical_id, m_MapPhysicalCpu.keys()) {
-        if(physical_id < 0)
+        if (physical_id < 0)
             continue;
-        PhysicalCpu& physical = m_MapPhysicalCpu[physical_id];
+        PhysicalCpu &physical = m_MapPhysicalCpu[physical_id];
         if (physical.logicalIsExisted(logical_id)) {
             return physical.logicalCpu(logical_id);
         }
@@ -182,8 +215,7 @@ void CpuInfo::setProcCpuinfo(LogicalCpu &logical, const QMap<QString, QString> &
     if ("mips64" == m_Arch || "loongarch64" == m_Arch) {
         logical.setCurFreq(mapInfo["cpu mhz"]);
         logical.setModel(mapInfo["cpu model"]);
-        if(logical.flags().isEmpty())
-        {
+        if (logical.flags().isEmpty()) {
             logical.setFlags(mapInfo["features"]);
         }
     }
@@ -255,7 +287,7 @@ int CpuInfo::readPhysicalID(const QString &path)
         return -1;
     QString info = file.readAll();
     file.close();
-    if("sw_64" == m_Arch && -1 == info.toInt()){
+    if ("sw_64" == m_Arch && -1 == info.toInt()) {
         return 0;
     }
     return info.toInt();
@@ -281,7 +313,10 @@ int CpuInfo::readThreadSiblingsListPath(const QString &path)
     }
     QString info = file.readAll();
     file.close();
-    return info.replace(",", "").toInt();
+
+    QStringList words = info.split(QRegExp("\\D"));
+
+    return words.isEmpty() ? 0 : words.first().toInt();
 }
 
 void CpuInfo::readCpuCache(const QString &path, LogicalCpu &lcpu)
