@@ -1,23 +1,7 @@
-/*
-* Copyright (C) 2019 ~ 2020 Uniontech Software Technology Co.,Ltd.
-*
-* Author:     Jun.Liu <liujuna@uniontech.com>
-*
-* Maintainer: Jun.Liu <liujuna@uniontech.com>
-*
-* This program is free software: you can redistribute it and/or modify
-* it under the terms of the GNU General Public License as published by
-* the Free Software Foundation, either version 3 of the License, or
-* any later version.
-*
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-* GNU General Public License for more details.
-*
-* You should have received a copy of the GNU General Public License
-* along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*/
+// Copyright (C) 2019 ~ 2020 Uniontech Software Technology Co.,Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #ifndef PHYSICALCPU_H
 #define PHYSICALCPU_H
@@ -37,7 +21,7 @@ public:
      * @param id
      * @param cpu
      */
-    void addCoreCpu(int id, const CoreCpu& cpu);
+    void addCoreCpu(int id, const CoreCpu &cpu);
 
     /**
      * @brief coreIsExisted
@@ -50,7 +34,7 @@ public:
      * @param id
      * @return
      */
-    CoreCpu& coreCpu(int id);
+    CoreCpu &coreCpu(int id);
 
     /**
      * @brief logicalIsExisted
@@ -64,13 +48,13 @@ public:
      * @param id
      * @return
      */
-    LogicalCpu& logicalCpu(int id);
+    LogicalCpu &logicalCpu(int id);
 
     /**
      * @brief getInfo
      * @param info
      */
-    void getInfo(QString& info);
+    void getInfo(QString &info);
 
     /**
      * @brief coreNum
@@ -89,6 +73,12 @@ public:
      */
     void diagPrintInfo();
 
+    /**
+     * @brief coreNums
+     * @return
+     */
+    QList<int> coreNums();
+
 private:
     int m_PhysicalCpu;                   //<! physical id
     QMap<int, CoreCpu> m_MapCoreCpu;      //<! core cpu
