@@ -1,3 +1,7 @@
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 // 项目自身文件
 #include "DeviceBluetooth.h"
 #include "DBusEnableInterface.h"
@@ -7,15 +11,12 @@
 
 DeviceBluetooth::DeviceBluetooth()
     : DeviceBaseInfo()
-    , m_Name("")
-    , m_Vendor("")
-    , m_Version("")
     , m_Model("")
     , m_MAC("")
     , m_LogicalName("")
     , m_BusInfo("")
     , m_Capabilities("")
-    , m_Driver("btusb")
+      //, m_Driver(""), m_Driver("btusb")
     , m_DriverVersion("")
     , m_MaximumPower("")
     , m_Speed("")
@@ -62,10 +63,17 @@ bool DeviceBluetooth::setInfoFromHwinfo(const QMap<QString, QString> &mapInfo)
     setAttribute(mapInfo, "Speed", m_Speed);
     setAttribute(mapInfo, "SysFS ID", m_SysPath);
     setAttribute(mapInfo, "Device", m_Name);
-    setAttribute(mapInfo, "Unique ID", m_SerialID);
-    m_UniqueID = m_SerialID;
+    setAttribute(mapInfo, "Unique ID", m_UniqueID);
+    // 防止Serial ID为空
+    if (m_SerialID.isEmpty())
+        m_SerialID = m_UniqueID;
+
     m_HardwareClass = "bluetooth";
 
+    setAttribute(mapInfo, "Module Alias", m_Modalias);
+    setAttribute(mapInfo, "VID_PID", m_VID_PID);
+    m_PhysID = m_VID_PID;
+
     // 判断是否核内驱动
     if (driverIsKernelIn(m_Driver)) {
         m_CanUninstall = false;
@@ -102,6 +110,24 @@ bool DeviceBluetooth::setInfoFromLshw(const QMap<QString, QString> &mapInfo)
     return true;
 }
 
+TomlFixMethod DeviceBluetooth::setInfoFromTomlOneByOne(const QMap<QString, QString> &mapInfo)
+{
+    TomlFixMethod ret = TOML_None;
+    // 添加基本信息
+    ret = setTomlAttribute(mapInfo, "Model", m_Model);
+    // 添加其他信息,成员变量
+    ret = setTomlAttribute(mapInfo, "Speed", m_Speed);
+    ret = setTomlAttribute(mapInfo, "Maximum Power", m_MaximumPower);
+    ret = setTomlAttribute(mapInfo, "Driver Version", m_DriverVersion);
+    ret = setTomlAttribute(mapInfo, "Capabilities", m_Capabilities);
+    ret = setTomlAttribute(mapInfo, "Bus Info", m_BusInfo);
+    ret = setTomlAttribute(mapInfo, "Logical Name", m_LogicalName);
+    ret = setTomlAttribute(mapInfo, "MAC Address", m_MAC);
+//3. 获取设备的其它信息
+    getOtherMapInfo(mapInfo);
+    return ret;
+}
+
 bool DeviceBluetooth::setInfoFromWifiInfo(const QMap<QString, QString> &mapInfo)
 {
     // 机器自身蓝牙
@@ -192,7 +218,7 @@ void DeviceBluetooth::initFilterKey()
 
     addFilterKey(QObject::tr("product"));
     addFilterKey(QObject::tr("description"));
-    addFilterKey(QObject::tr("physical id"));
+    // addFilterKey(QObject::tr("physical id"));
     addFilterKey(QObject::tr("Class"));
     addFilterKey(QObject::tr("Powered"));
     addFilterKey(QObject::tr("Discoverable"));
@@ -214,6 +240,8 @@ void DeviceBluetooth::loadBaseDeviceInfo()
 void DeviceBluetooth::loadOtherDeviceInfo()
 {
     // 添加其他信息,成员变量
+    addOtherDeviceInfo(tr("Module Alias"), m_Modalias);
+    addOtherDeviceInfo(tr("Physical ID"), m_PhysID);
     addOtherDeviceInfo(tr("Speed"), m_Speed);
     addOtherDeviceInfo(tr("Maximum Power"), m_MaximumPower);
     addOtherDeviceInfo(tr("Driver Version"), m_DriverVersion);
