@@ -1,23 +1,7 @@
-/*
-* Copyright (C) 2019 ~ 2020 Uniontech Software Technology Co.,Ltd.
-*
-* Author:     Jun.Liu <liujuna@uniontech.com>
-*
-* Maintainer: XiaoMei.Ji <jixiaomei@uniontech.com>
-*
-* This program is free software: you can redistribute it and/or modify
-* it under the terms of the GNU General Public License as published by
-* the Free Software Foundation, either version 3 of the License, or
-* any later version.
-*
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-* GNU General Public License for more details.
-*
-* You should have received a copy of the GNU General Public License
-* along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*/
+// Copyright (C) 2019 ~ 2020 Uniontech Software Technology Co.,Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #ifndef DEVICECOMPUTER_H
 #define DEVICECOMPUTER_H
@@ -34,6 +18,13 @@ class DeviceComputer : public DeviceBaseInfo
 public:
     DeviceComputer();
 
+/**
+ * @brief setInfoFromTomlOneByOne:设置从toml里面获取的信息
+ * @param mapInfo:由toml获取的信息map
+ * @return枚举值
+ */
+TomlFixMethod setInfoFromTomlOneByOne(const QMap<QString, QString> &mapInfo);
+
     /**
      * @brief name:获取名称属性值
      * @return QString:名称属性值
@@ -134,10 +125,7 @@ private:
     QString            m_HomeUrl;
     QString            m_OsDescription;
     QString            m_OS;
-    QString            m_Vendor;
-    QString            m_Name;
     QString            m_Type;
-    QString            m_Driver;
 };
 
 #endif // DEVICECOMPUTER_H
