@@ -1,23 +1,7 @@
-/*
-* Copyright (C) 2019 ~ 2020 Uniontech Software Technology Co.,Ltd.
-*
-* Author:     Jun.Liu <liujuna@uniontech.com>
-*
-* Maintainer: XiaoMei.Ji <jixiaomei@uniontech.com>
-*
-* This program is free software: you can redistribute it and/or modify
-* it under the terms of the GNU General Public License as published by
-* the Free Software Foundation, either version 3 of the License, or
-* any later version.
-*
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-* GNU General Public License for more details.
-*
-* You should have received a copy of the GNU General Public License
-* along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*/
+// Copyright (C) 2019 ~ 2020 Uniontech Software Technology Co.,Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #ifndef DEVICECPU_H
 #define DEVICECPU_H
@@ -102,6 +86,13 @@ public:
      */
     void setFrequencyIsCur(const bool &flag);
 
+    /**
+        * @brief setInfoFromTomlOneByOne:设置从toml里面获取的信息
+        * @param mapInfo:由toml获取的信息map
+        * @return枚举值
+        */
+    TomlFixMethod setInfoFromTomlOneByOne(const QMap<QString, QString> &mapInfo);
+
 protected:
 
     /**
@@ -152,8 +143,7 @@ private:
     void setRefreshInfoFromLscpu(const QMap<QString, QString> &mapInfo);
 
 private:
-    QString           m_Vendor;             //<! 制造商
-    QString           m_Name;               //<! 名称
+
     QString           m_PhysicalID;         //<! 处理器ID
     QString           m_CoreID;             //<! 核心ID
     QString           m_ThreadNum;          //<! 线程数
@@ -176,7 +166,6 @@ private:
     // 这个是cpu的逻辑处理器个数，而不是core的逻辑处理器个数
     int               m_LogicalCPUNum;      //<! 逻辑处理器个数
     int               m_CPUCoreNum;         //<! cpu核数
-    QString           m_Driver;
     bool              m_FrequencyIsRange;   //<! 频率显示的是范围还是最大值
     bool              m_FrequencyIsCur;     //<! 频率显示是当前还是最大值
 
