@@ -1,3 +1,7 @@
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 // 项目自身文件
 #include "DeviceImage.h"
 #include "DeviceManager.h"
@@ -5,13 +9,9 @@
 
 DeviceImage::DeviceImage()
     : DeviceBaseInfo()
-    , m_Name("")
-    , m_Vendor("")
     , m_Model("")
-    , m_Version("")
     , m_BusInfo("")
     , m_Capabilities("")
-    , m_Driver("")
     , m_MaximumPower("")
     , m_Speed("")
 {
@@ -37,6 +37,23 @@ void DeviceImage::setInfoFromLshw(const QMap<QString, QString> &mapInfo)
     }
 }
 
+TomlFixMethod DeviceImage::setInfoFromTomlOneByOne(const QMap<QString, QString> &mapInfo)
+{
+    TomlFixMethod ret = TOML_None;
+
+    // 添加基本信息
+    ret = setTomlAttribute(mapInfo, "Model", m_Model);
+    ret = setTomlAttribute(mapInfo, "Bus Info", m_BusInfo);
+    // 添加其他信息,成员变量
+    ret = setTomlAttribute(mapInfo, "Speed", m_Speed);
+    ret = setTomlAttribute(mapInfo, "Maximum Power", m_MaximumPower);
+    ret = setTomlAttribute(mapInfo, "Capabilities", m_Capabilities);
+    ret = setTomlAttribute(mapInfo, "Serial Number", m_SerialID);
+//3. 获取设备的其它信息
+    getOtherMapInfo(mapInfo);
+    return ret;
+}
+
 void DeviceImage::setInfoFromHwinfo(const QMap<QString, QString> &mapInfo)
 {
     if (mapInfo.find("unique_id") != mapInfo.end()) {
@@ -54,8 +71,10 @@ void DeviceImage::setInfoFromHwinfo(const QMap<QString, QString> &mapInfo)
         m_Enable = false;
     }
     setAttribute(mapInfo, "Serial ID", m_SerialID);
-    setAttribute(mapInfo, "Unique ID", m_SerialID);
-    m_UniqueID = m_SerialID;
+    setAttribute(mapInfo, "Unique ID", m_UniqueID);
+    // 防止Serial ID为空
+    if (m_SerialID.isEmpty())
+        m_SerialID = m_UniqueID;
     setAttribute(mapInfo, "SysFS ID", m_SysPath);
     setAttribute(mapInfo, "Device", m_Name);
     setAttribute(mapInfo, "Vendor", m_Vendor);
@@ -65,6 +84,9 @@ void DeviceImage::setInfoFromHwinfo(const QMap<QString, QString> &mapInfo)
     setAttribute(mapInfo, "Driver", m_Driver, true);//
     setAttribute(mapInfo, "Driver Modules", m_Driver, true);
     setAttribute(mapInfo, "Speed", m_Speed);
+    setAttribute(mapInfo, "Module Alias", m_Modalias);
+    setAttribute(mapInfo, "VID_PID", m_VID_PID);
+    m_PhysID = m_VID_PID;
     if (driverIsKernelIn(m_Driver)) {
         m_CanUninstall = false;
     }
@@ -144,11 +166,14 @@ void DeviceImage::loadBaseDeviceInfo()
 void DeviceImage::loadOtherDeviceInfo()
 {
     // 添加其他信息,成员变量
+    addOtherDeviceInfo(tr("Module Alias"), m_Modalias);
+    addOtherDeviceInfo(tr("Physical ID"), m_PhysID);
     addOtherDeviceInfo(tr("Speed"), m_Speed);
     addOtherDeviceInfo(tr("Maximum Power"), m_MaximumPower);
     addOtherDeviceInfo(tr("Driver"), m_Driver);
     addOtherDeviceInfo(tr("Capabilities"), m_Capabilities);
-    addOtherDeviceInfo(tr("Serial Number"), m_SerialID);
+    if (m_SerialID != m_UniqueID)
+        addOtherDeviceInfo(tr("Serial Number"), m_SerialID);
 
     // 将QMap<QString, QString>内容转存为QList<QPair<QString, QString>>
     mapInfoToList();
