@@ -1,30 +1,14 @@
-/*
-* Copyright (C) 2019 ~ 2020 Uniontech Software Technology Co.,Ltd.
-*
-* Author:     Jun.Liu <liujuna@uniontech.com>
-*
-* Maintainer: XiaoMei.Ji <jixiaomei@uniontech.com>
-* Maintainer: Jun.Liu <liujuna@uniontech.com>
-*
-* This program is free software: you can redistribute it and/or modify
-* it under the terms of the GNU General Public License as published by
-* the Free Software Foundation, either version 3 of the License, or
-* any later version.
-*
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-* GNU General Public License for more details.
-*
-* You should have received a copy of the GNU General Public License
-* along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*/
+// Copyright (C) 2019 ~ 2020 Uniontech Software Technology Co.,Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #ifndef DEVICEMANAGER_H
 #define DEVICEMANAGER_H
 
 #include "document.h"
 #include "xlsxdocument.h"
+#include "GenerateDevicePool.h"
 
 #include <QList>
 #include <QMap>
@@ -54,6 +38,17 @@ class DeviceCdrom;
 class DeviceInput;
 class DeviceBaseInfo;
 
+/**
+ * @brief The TomlFixMethod enum
+ * 用来标识对toml信息处理的的结果(包括不操作、部份覆盖显示、删除不显示,全覆盖显示四种情况)
+ */
+enum TomlFixMethod {
+    TOML_None,
+    TOML_Cover, // 覆掉关键词的值
+    TOML_nouse,  //对应TOML的nouse ，清掉关键词的值
+    TOML_Del   //去掉该设备
+};
+
 /**
  * @brief The DeviceManager class
  * 设备的管理类(包括设备的获取、增加、修改)
@@ -94,6 +89,54 @@ public:
      */
     bool getDeviceList(const QString &name, QList<DeviceBaseInfo *> &lst);
 
+   /**
+    * @brief convertDeviceListAddr : 获取设备列表地址
+    * @param name : 该设备的类型地址
+    * @return ：返回设备列表地址
+    */
+   QList<DeviceBaseInfo *> *convertDeviceListAddr(DeviceType deviceType);
+
+    /**
+     * @brief convertDeviceList : 获取设备列表
+     * @param name : 该设备的类型
+     * @return ：返回设备列表
+     */
+    QList<DeviceBaseInfo *>  convertDeviceList(DeviceType deviceType);
+    QString  convertDeviceTomlClassName(DeviceType deviceType);
+    TomlFixMethod tomlDeviceSet(DeviceType deviceType,  DeviceBaseInfo *device, const QMap<QString, QString> &mapInfo);
+    void tomlDeviceSet(DeviceType deviceType);
+    void tomlDeviceDel(DeviceType deviceType, DeviceBaseInfo *const device);
+    void tomlDeviceAdd(DeviceType deviceType, DeviceBaseInfo *const device);
+    /**
+     * @brief 
+     *   toml 方案内容定义：
+     * 硬件 IDS 参考内核 Module Alias 规则标准，示例 Module Alias: "pci:v00008086d0000A3C8sv00001849sd0000A3C8bc06sc01i00"
+     *  若有的设备读不到Module Alias，请以格式“设备分类名+ : + v0000 + Vendor_ID + d0000 + Product_ID + sv0000+SubVendor_ID+sd0000+SubProduct_ID” 作为硬件IDS，若  SubVendor_ID 和 SubProduct_ID 无，则填默认为0000，格式尽量跟 Module Alias 一样
+     *  若有的设备读不到 Vendor_ID+Product_ID，请以格式“设备分类名称 + : + Vendor + Name”作为硬件 IDS ，所有字母全转化为小写，并去掉不可显示字符和空格
+     
+     *
+     * @brief PhysID
+     * @param mapInfo
+     * @return QString
+     */
+    QString PhysID(const QMap<QString, QString> &mapInfo, const QString &key);
+
+    DeviceBaseInfo *createDevice(DeviceType deviceType);
+
+    /**
+     * @brief getAudioDevice 获取设备
+     * @param name  见 添加设备类型与设备指针列表的映射关系 void DeviceManager::setDeviceListClass()
+     * @param  KeyID  "Module Alias"  "VID_PID"
+     * @return
+     */
+    DeviceBaseInfo *findByModalias(DeviceType deviceType, const QString &modalias);
+    DeviceBaseInfo *findByVIDPID(DeviceType deviceType, const QString &vid, const QString &pid);
+    DeviceBaseInfo *findByVendorName(DeviceType deviceType, const QString &vendor, const QString &name);
+    
+    bool findByModalias(DeviceType deviceType, DeviceBaseInfo *device, const QString &modalias);
+    bool findByVIDPID(DeviceType deviceType, DeviceBaseInfo *device, const QString &vid, const QString &pid);
+    bool findByVendorName(DeviceType deviceType, DeviceBaseInfo *device, const QString &vendor, const QString &name);
+
     /**
      * @brief getBluetoothAtIndex 根据索引获取device
      * @param index
@@ -114,7 +157,7 @@ public:
      * @param unique_id
      * @return
      */
-    DeviceBaseInfo* getMouseDevice(const QString& unique_id);
+    DeviceBaseInfo *getMouseDevice(const QString &unique_id);
 
     /**
      * @brief addMouseInfoFromLshw:添加从lshw获取的鼠标信息
@@ -275,7 +318,7 @@ public:
      * @param unique_id
      * @return
      */
-    DeviceBaseInfo* getBluetoothDevice(const QString& unique_id);
+    DeviceBaseInfo *getBluetoothDevice(const QString &unique_id);
 
     // 音频设备相关
     /**
@@ -284,6 +327,13 @@ public:
      */
     void addAudioDevice(DeviceAudio *const device);
 
+    // 音频设备相关
+    /**
+     * @brief delAudioDevice: del声卡
+     * @param device:被del的声卡
+     */
+    void delAudioDevice(DeviceAudio *const device);
+
     /**
      * @brief addAudioDevice:去除列表中重复的已禁声卡
      * @param device:
@@ -295,7 +345,7 @@ public:
      * @param path
      * @return
      */
-    DeviceBaseInfo* getAudioDevice(const QString& path);
+    DeviceBaseInfo *getAudioDevice(const QString &path);
 
     /**
      * @brief setAudioInfoFromLshw:设置由lshw获取的声卡信息
@@ -303,6 +353,12 @@ public:
      */
     void setAudioInfoFromLshw(const QMap<QString, QString> &mapInfo);
 
+    /**
+     * @brief setAudioInfoFromLshw:设置由lshw获取的声卡信息
+     * @param mapInfo:由lshw获取的声卡信息map
+     */
+    void setAudioInfoFromToml(const QMap<QString, QString> &mapInfo);
+
     /**
      * @brief setAudioInfoFrom_sysFS:设置由sysFS获取的声卡信息
      * @param mapInfo:由sysFS获取的声卡信息map
@@ -313,7 +369,7 @@ public:
     //  * @brief setAudioChipFromDmesg:从Dmesg获取的信息设置声卡芯片型号
     //  * @param info:声卡芯片型号
     //  */
-     void setAudioChipFromDmesg(const QString &info);
+    void setAudioChipFromDmesg(const QString &info);
 
     // 网络设备相关
     /**
@@ -333,7 +389,7 @@ public:
      * @param busInfo
      * @return
      */
-    DeviceBaseInfo * getNetworkDevice(const QString& unique_id);
+    DeviceBaseInfo *getNetworkDevice(const QString &unique_id);
 
     /**
      * @brief correctNetworkLinkStatus:校正网络连接状态
@@ -365,7 +421,7 @@ public:
      * @param unique_id
      * @return
      */
-    DeviceBaseInfo* getImageDevice(const QString& unique_id);
+    DeviceBaseInfo *getImageDevice(const QString &unique_id);
 
     /**
      * @brief setCameraInfoFromLshw:设置由lshw获取的图像设备信息
@@ -398,7 +454,7 @@ public:
      * @param unique_id
      * @return
      */
-    DeviceBaseInfo* getOthersDevice(const QString& unique_id);
+    DeviceBaseInfo *getOthersDevice(const QString &unique_id);
 
     /**
      * @brief addOthersDeviceFromHwinfo:添加由hwinfo获取的其他设备信息
