@@ -1,3 +1,7 @@
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 // 项目自身文件
 #include "DeviceMemory.h"
 #include "commonfunction.h"
@@ -37,8 +41,6 @@ void DeviceMemory::setInfoFromLshw(const QMap<QString, QString> &mapInfo)
 
     // 设置内存速率
     setAttribute(mapInfo, "clock", m_Speed);
-    if (m_Speed.contains("MT/s"))
-        m_Speed.replace("MT/s", "MHz");
 
     // 由lshw设置基本信息
     setAttribute(mapInfo, "width", m_TotalBandwidth);
@@ -48,6 +50,27 @@ void DeviceMemory::setInfoFromLshw(const QMap<QString, QString> &mapInfo)
     getOtherMapInfo(mapInfo);
 }
 
+TomlFixMethod DeviceMemory::setInfoFromTomlOneByOne(const QMap<QString, QString> &mapInfo)
+{
+    TomlFixMethod ret = TOML_None;
+        // 添加基本信息
+    ret = setTomlAttribute(mapInfo, "Size", m_Size);
+    ret = setTomlAttribute(mapInfo, "Type", m_Type);
+    ret = setTomlAttribute(mapInfo, "Speed", m_Speed);
+    ret = setTomlAttribute(mapInfo, "Total Width", m_TotalBandwidth);
+    ret = setTomlAttribute(mapInfo, "Locator", m_Locator);
+    ret = setTomlAttribute(mapInfo, "Serial Number", m_SerialNumber);
+    // 添加其他信息,成员变量
+    ret = setTomlAttribute(mapInfo, "Configured Voltage", m_ConfiguredVoltage);
+    ret = setTomlAttribute(mapInfo, "Maximum Voltage", m_MaximumVoltage);
+    ret = setTomlAttribute(mapInfo, "Minimum Voltage", m_MinimumVoltage);
+    ret = setTomlAttribute(mapInfo, "Configured Speed", m_ConfiguredSpeed);
+    ret = setTomlAttribute(mapInfo, "Data Width", m_DataBandwidth);
+//3. 获取设备的其它信息
+    getOtherMapInfo(mapInfo);
+    return ret;
+}
+
 bool DeviceMemory::setInfoFromDmidecode(const QMap<QString, QString> &mapInfo)
 {
     // 由 locator属性判断是否为同一内存条
@@ -58,10 +81,9 @@ bool DeviceMemory::setInfoFromDmidecode(const QMap<QString, QString> &mapInfo)
     setAttribute(mapInfo, "Part Number", m_Name);
     setAttribute(mapInfo, "Serial Number", m_SerialNumber);
 
+    setAttribute(mapInfo, "Speed", m_Speed);
     // 设置配置频率
     setAttribute(mapInfo, "Configured Memory Speed", m_ConfiguredSpeed);
-    if (m_ConfiguredSpeed.contains("MT/s"))
-        m_ConfiguredSpeed.replace("MT/s", "MHz");
 
     // 由dmidecode设置基本属性
     setAttribute(mapInfo, "Minimum Voltage", m_MinimumVoltage);
@@ -123,7 +145,7 @@ void DeviceMemory::loadOtherDeviceInfo()
 {
     // 倒序，头插，保证原来的顺序
     // 添加其他信息,成员变量
-    if(Common::boardVendorType().isEmpty()){
+    if (Common::boardVendorType().isEmpty()) {
         addOtherDeviceInfo(tr("Configured Voltage"), m_ConfiguredVoltage);
         addOtherDeviceInfo(tr("Maximum Voltage"), m_MaximumVoltage);
         addOtherDeviceInfo(tr("Minimum Voltage"), m_MinimumVoltage);
@@ -188,7 +210,7 @@ const QString DeviceMemory::getOverviewInfo()
     // 获取概况信息
     QString ov;
     QString nameStr = m_Name != "" ? m_Name : m_Vendor;
-    if(nameStr == "--")
+    if (nameStr == "--")
         nameStr.clear();
     ov += QString("%1(%2 %3 %4)") \
           .arg(m_Size) \
