@@ -1,24 +1,7 @@
-/*
-* Copyright (C) 2019 ~ 2020 Uniontech Software Technology Co.,Ltd.
-*
-* Author:     Jun.Liu <liujuna@uniontech.com>
-*
-* Maintainer: XiaoMei.Ji <jixiaomei@uniontech.com>
-* Maintainer: Jun.Liu <liujuna@uniontech.com>
-*
-* This program is free software: you can redistribute it and/or modify
-* it under the terms of the GNU General Public License as published by
-* the Free Software Foundation, either version 3 of the License, or
-* any later version.
-*
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-* GNU General Public License for more details.
-*
-* You should have received a copy of the GNU General Public License
-* along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*/
+// Copyright (C) 2019 ~ 2020 Uniontech Software Technology Co.,Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #ifndef DEVICEMONITOR_H
 #define DEVICEMONITOR_H
@@ -42,6 +25,13 @@ public:
      */
     void setInfoFromHwinfo(const QMap<QString, QString> &mapInfo);
 
+  /**
+      * @brief setInfoFromTomlOneByOne:设置从toml里面获取的信息
+      * @param mapInfo:由toml获取的信息map
+      * @return枚举值
+      */
+   TomlFixMethod setInfoFromTomlOneByOne(const QMap<QString, QString> &mapInfo);
+   
     /**
      * @brief setInfoFromXradr:设置从xrandr中获取的信息
      * @param main:主显示器信息
@@ -190,8 +180,6 @@ private:
 
 
 private:
-    QString         m_Name;              //<! 【名称】
-    QString         m_Vendor;            //<! 【制造商】
     QString         m_Model;             //<! 【型号】
     QString         m_DisplayInput;      //<! 【显示输入】
     QString         m_VGA;               //<! 【VGA】
@@ -205,7 +193,6 @@ private:
     QString         m_SerialNumber;      //<! 【流水号】
     QString         m_ProductionWeek;    //<! 【生产年月】
     QString         m_SupportResolution; //<!  支持的屏幕分辨率
-    QString         m_Driver;
 
     int             m_Width;             //<!  屏幕的宽度
     int             m_Height;            //<!  屏幕的高度
