@@ -1,15 +1,18 @@
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 // 项目自身文件
 #include "DeviceNetwork.h"
 #include "DBusEnableInterface.h"
 #include "commonfunction.h"
 
 #include <QFileInfo>
+#include <QProcess>
 
 DeviceNetwork::DeviceNetwork()
     : DeviceBaseInfo()
-    , m_Name("")
-    , m_Vendor("")
-    , m_Model(""), m_Version("")
+    , m_Model("")//, m_Version("")
     , m_BusInfo("")
     , m_LogicalName("")
     , m_MACAddress("")
@@ -20,7 +23,6 @@ DeviceNetwork::DeviceNetwork()
     , m_Capabilities("")
     , m_Autonegotiation("")
     , m_Broadcast("")
-    , m_Driver("")
     , m_DriverModules("")
     , m_DriverVersion("")
     , m_Duplex("")
@@ -50,8 +52,29 @@ void DeviceNetwork::setInfoFromLshw(const QMap<QString, QString> &mapInfo)
     // 设置由lshw获取的信息
     setAttribute(mapInfo, "description", m_Model);
     setAttribute(mapInfo, "product", m_Name);
-    setAttribute(mapInfo, "description", m_Name, false);
     setAttribute(mapInfo, "vendor", m_Vendor);
+    if (m_SysPath.contains("usb")) {
+        QProcess process;
+        QString vendorId = getVendorOrModelId(m_SysPath, true).trimmed();
+        QString deviceId = getVendorOrModelId(m_SysPath, false).trimmed();
+        process.start("lsusb -v -d " + vendorId + ":" + deviceId);
+        process.waitForFinished(-1);
+
+        QString output = process.readAllStandardOutput();
+
+        foreach (QString out, output.split("\n")) {
+            if (!m_Vendor.isEmpty() && !m_Name.isEmpty())
+                break;
+            // 从USB设备获取制造商和设备名称
+            if (m_Vendor.isEmpty() && out.contains("idVendor", Qt::CaseSensitive)) {
+                m_Vendor = out.remove(0, out.indexOf(vendorId) + 4).trimmed();
+            } else if (m_Name.isEmpty() && out.contains("idProduct", Qt::CaseSensitive)) {
+                m_Name = out.remove(0, out.indexOf(deviceId) + 4).trimmed();
+            }
+        }
+    } else {
+        setAttribute(mapInfo, "description", m_Name, false);
+    }
     setAttribute(mapInfo, "version", m_Version);
     setAttribute(mapInfo, "bus info", m_BusInfo);
     setAttribute(mapInfo, "logical name", m_LogicalName);
@@ -82,6 +105,37 @@ void DeviceNetwork::setInfoFromLshw(const QMap<QString, QString> &mapInfo)
     getOtherMapInfo(mapInfo);
 }
 
+TomlFixMethod DeviceNetwork::setInfoFromTomlOneByOne(const QMap<QString, QString> &mapInfo)
+{
+    TomlFixMethod ret = TOML_None;
+    // 添加基本信息
+    ret = setTomlAttribute(mapInfo, "Type", m_Model);
+    ret = setTomlAttribute(mapInfo, "Bus Info", m_BusInfo);
+    ret = setTomlAttribute(mapInfo, "Capabilities", m_Capabilities);
+    ret = setTomlAttribute(mapInfo, "Driver Version", m_DriverVersion);
+    // 添加其他信息,成员变量
+    ret = setTomlAttribute(mapInfo, "Maximum Rate", m_Capacity);
+    ret = setTomlAttribute(mapInfo, "Negotiation Rate", m_Speed);
+    ret = setTomlAttribute(mapInfo, "Port", m_Port);
+    ret = setTomlAttribute(mapInfo, "Multicast", m_Multicast);
+    ret = setTomlAttribute(mapInfo, "Link", m_Link);
+    ret = setTomlAttribute(mapInfo, "Latency", m_Latency);
+    ret = setTomlAttribute(mapInfo, "IP", m_Ip);
+    ret = setTomlAttribute(mapInfo, "Firmware", m_Firmware);
+    ret = setTomlAttribute(mapInfo, "Duplex", m_Duplex);
+    ret = setTomlAttribute(mapInfo, "Broadcast", m_Broadcast);
+    ret = setTomlAttribute(mapInfo, "Auto Negotiation", m_Autonegotiation);
+//    ret = setTomlAttribute(mapInfo, "Clock", m_Clock);
+//    ret = setTomlAttribute(mapInfo, "Width", m_Width);
+    ret = setTomlAttribute(mapInfo, "Memory Address", m_Memory);
+    ret = setTomlAttribute(mapInfo, "IRQ", m_Irq);
+    ret = setTomlAttribute(mapInfo, "MAC Address", m_MACAddress);
+    ret = setTomlAttribute(mapInfo, "Logical Name", m_LogicalName);
+//3. 获取设备的其它信息
+    getOtherMapInfo(mapInfo);
+    return ret;
+}
+
 bool DeviceNetwork::setInfoFromHwinfo(const QMap<QString, QString> &mapInfo)
 {
     if (mapInfo.find("path") != mapInfo.end()) {
@@ -100,11 +154,19 @@ bool DeviceNetwork::setInfoFromHwinfo(const QMap<QString, QString> &mapInfo)
     setAttribute(mapInfo, "SysFS Device Link", m_SysPath);
     setAttribute(mapInfo, "Driver", m_Driver);
     setAttribute(mapInfo, "Driver Modules", m_DriverModules);
+    setAttribute(mapInfo, "Module Alias", m_Modalias);
+    setAttribute(mapInfo, "VID_PID", m_VID_PID);
+    m_PhysID = m_VID_PID;
 
     if (driverIsKernelIn(m_DriverModules) || driverIsKernelIn(m_Driver)) {
         m_CanUninstall = false;
     }
 
+    // 获取设备路径
+    if (m_SysPath.isEmpty() && !mapInfo.contains("SysFS Device Link")
+            && mapInfo["SysFS ID"].startsWith("/devices")) {
+        m_SysPath = mapInfo["SysFS ID"];
+    }
     // 判断是否是无线网卡
     setIsWireless(mapInfo["SysFS ID"]);
 
@@ -209,7 +271,6 @@ void DeviceNetwork::initFilterKey()
 {
     // 初始化可显示属性
     addFilterKey(QObject::tr("ioport"));
-    addFilterKey(QObject::tr("physical id"));
     addFilterKey(QObject::tr("network"));
 }
 
@@ -229,6 +290,8 @@ void DeviceNetwork::loadBaseDeviceInfo()
 void DeviceNetwork::loadOtherDeviceInfo()
 {
     // 添加其他信息,成员变量
+    addOtherDeviceInfo(tr("Module Alias"), m_Modalias);
+    addOtherDeviceInfo(tr("Physical ID"), m_PhysID);
     addOtherDeviceInfo(tr("Maximum Rate"), m_Capacity);        // 1050需求 容量改为最大速率
     addOtherDeviceInfo(tr("Negotiation Rate"), m_Speed);       // 1050需求 速度改为协商速率
     addOtherDeviceInfo(tr("Port"), m_Port);
@@ -240,8 +303,8 @@ void DeviceNetwork::loadOtherDeviceInfo()
     addOtherDeviceInfo(tr("Duplex"), m_Duplex);
     addOtherDeviceInfo(tr("Broadcast"), m_Broadcast);
     addOtherDeviceInfo(tr("Auto Negotiation"), m_Autonegotiation);
-    addOtherDeviceInfo(tr("Clock"), m_Clock);
-    addOtherDeviceInfo(tr("Width"), m_Width);
+//    addOtherDeviceInfo(tr("Clock"), m_Clock);
+//    addOtherDeviceInfo(tr("Width"), m_Width);
     addOtherDeviceInfo(tr("Memory Address"), m_Memory);        // 1050需求 内存改为内存地址
     addOtherDeviceInfo(tr("IRQ"), m_Irq);
     addOtherDeviceInfo(tr("MAC Address"), m_MACAddress);
@@ -251,6 +314,13 @@ void DeviceNetwork::loadOtherDeviceInfo()
     mapInfoToList();
 }
 
+void DeviceNetwork::loadTableHeader()
+{
+    m_TableHeader.append(tr("Name"));
+    m_TableHeader.append(tr("Vendor"));
+    m_TableHeader.append(tr("Type"));
+}
+
 void DeviceNetwork::loadTableData()
 {
     // 根据是否禁用设置设备名称
