@@ -1,24 +1,7 @@
-/*
-* Copyright (C) 2019 ~ 2020 Uniontech Software Technology Co.,Ltd.
-*
-* Author:     Jun.Liu <liujuna@uniontech.com>
-*
-* Maintainer: XiaoMei.Ji <jixiaomei@uniontech.com>
-* Maintainer: Jun.Liu <liujuna@uniontech.com>
-*
-* This program is free software: you can redistribute it and/or modify
-* it under the terms of the GNU General Public License as published by
-* the Free Software Foundation, either version 3 of the License, or
-* any later version.
-*
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-* GNU General Public License for more details.
-*
-* You should have received a copy of the GNU General Public License
-* along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*/
+// Copyright (C) 2019 ~ 2020 Uniontech Software Technology Co.,Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #ifndef DEVICENETWORK_H
 #define DEVICENETWORK_H
@@ -42,6 +25,13 @@ public:
      */
     void setInfoFromLshw(const QMap<QString, QString> &mapInfo);
 
+  /**
+      * @brief setInfoFromTomlOneByOne:设置从toml里面获取的信息
+      * @param mapInfo:由toml获取的信息map
+      * @return枚举值
+      */
+   TomlFixMethod setInfoFromTomlOneByOne(const QMap<QString, QString> &mapInfo);
+   
     /**
      * @brief setInfoFromHwinfo:设置由hwinfo --network命令获取的设备信息
      * @param mapInfo:由hwinfo获取的信息map
@@ -140,16 +130,19 @@ protected:
      */
     void loadOtherDeviceInfo() override;
 
+    /**
+     * @brief loadTableHeader : 过去表格的表头数据
+     */
+    void loadTableHeader() override;
+
     /**
      * @brief loadTableData:加载表头信息
      */
     void loadTableData() override;
 
 private:
-    QString             m_Name;                         //<! 【名称】
-    QString             m_Vendor;                       //<! 【制造商】
+
     QString             m_Model;                        //<! 【型号】
-    QString             m_Version;                      //<! 【版本】
     QString             m_BusInfo;                      //<! 【总线信息】
     QString             m_LogicalName;                  //<! 【逻辑名称】
     QString             m_MACAddress;                   //<! 【物理地址】
@@ -160,7 +153,6 @@ private:
     QString             m_Capabilities;                 //<! 【功能】
     QString             m_Autonegotiation;              //<! 【自动协商】
     QString             m_Broadcast;                    //<! 【广播】
-    QString             m_Driver;                       //<! 【驱动】
     QString             m_DriverModules;                //<!  driver modules
     QString             m_DriverVersion;                //<! 【驱动】
     QString             m_Duplex;                       //<! 【双工】
