@@ -1,26 +1,43 @@
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 // 项目自身文件
 #include "DeviceOtherPCI.h"
 
 DeviceOtherPCI::DeviceOtherPCI()
     : DeviceBaseInfo()
-    , m_Name("")
-    , m_Vendor("")
     , m_Model("")
-    , m_Version("")
     , m_BusInfo("")
     , m_Width("")
     , m_Clock("")
     , m_Capabilities("")
-    , m_Description("")
     , m_Irq("")
     , m_Memory("")
-    , m_Driver("")
     , m_Latency("")
     , m_InputOutput("")
 {
 
 }
 
+TomlFixMethod DeviceOtherPCI::setInfoFromTomlOneByOne(const QMap<QString, QString> &mapInfo)
+{
+    TomlFixMethod ret = TOML_None;
+   // 添加基本信息
+    ret = setTomlAttribute(mapInfo, "Model", m_Model);
+    ret = setTomlAttribute(mapInfo, "Bus Info", m_BusInfo);
+
+    // 添加其他信息,成员变量
+    ret = setTomlAttribute(mapInfo, "Input/Output", m_InputOutput);
+    ret = setTomlAttribute(mapInfo, "Memory", m_Memory);
+    ret = setTomlAttribute(mapInfo, "IRQ", m_Irq);
+    ret = setTomlAttribute(mapInfo, "Latency", m_Latency);
+    ret = setTomlAttribute(mapInfo, "Capabilities", m_Version);
+//3. 获取设备的其它信息
+    getOtherMapInfo(mapInfo);
+    return ret;
+}
+
 const QString &DeviceOtherPCI::name()const
 {
     return m_Name;
@@ -68,8 +85,8 @@ void DeviceOtherPCI::loadOtherDeviceInfo()
     addOtherDeviceInfo(tr("Memory"), m_Memory);
     addOtherDeviceInfo(tr("IRQ"), m_Irq);
     addOtherDeviceInfo(tr("Latency"), m_Latency);
-    addOtherDeviceInfo(tr("Clock"), m_Clock);
-    addOtherDeviceInfo(tr("Width"), m_Width);
+//    addOtherDeviceInfo(tr("Clock"), m_Clock);
+//    addOtherDeviceInfo(tr("Width"), m_Width);
     addOtherDeviceInfo(tr("Driver"), m_Driver);
     addOtherDeviceInfo(tr("Capabilities"), m_Version);
 
