@@ -1,12 +1,17 @@
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 // 项目自身文件
 #include "CmdTool.h"
-
+#include <QDir>
 #include <cmath>
 
 // Qt库文件
 #include<QDebug>
 #include<QDateTime>
 #include<QMutex>
+#include <QCryptographicHash>
 
 // 其它头文件
 #include "../commondefine.h"
@@ -142,6 +147,129 @@ QMap<QString, QList<QMap<QString, QString> > > &CmdTool::cmdInfo()
 {
     return m_cmdInfo;
 }
+/*
+使用 sudo dmidecode -t 1 命令查询结果下的关键字：Manufacturer、Product Name、Version、Serial Number，取其值，
+文件取名以`oeminfo_`开头，取名格式为《oeminfo_manufacturer_productname_version_serialnumber.toml，
+后文简称为：《oeminfo_system.toml》文件名字母全转化为小写，并去掉不可显示特殊字符和空格。并基于此进行匹配。
+文件路径存放在/etc/deepin/hardware
+*/
+QString CmdTool::loadOemTomlFileName(const QMap<QString, QString> &mapInfo)
+{
+    bool tomlFileRead = false;
+    if (mapInfo.size() <= 0)
+        return QString();
+
+    QString tomlFileName;
+    //获取文件名字《oeminfo_manufacturer_productname_version_serialnumber.toml，
+    if (mapInfo.contains("Manufacturer")
+            && mapInfo.contains("Manufacturer")
+            && mapInfo.contains("Product Name")
+            && mapInfo.contains("Version")
+            && mapInfo.contains("Serial Number")) {
+        QString Manufacturer = mapInfo["Manufacturer"];
+        QString productname = mapInfo["Product Name"];
+        QString version = mapInfo["Version"];
+        QString serialnumber = mapInfo["Serial Number"];
+
+        if (Manufacturer.contains("N/A"))  Manufacturer = "";
+        if (productname.contains("N/A"))  productname = "";
+        if (version.contains("N/A"))  version = "";
+        if (serialnumber.contains("N/A"))  serialnumber = "";
+
+        QRegExp regExp("[-/'~!@#$%^&*(){}:;,.\"\\|~`]");
+        QString replace = "";         // 这里是将特殊字符换为空字符串,""代表直接去掉
+        Manufacturer = Manufacturer.replace(regExp, replace);
+        productname = productname.replace(regExp, replace);
+        version = version.replace(regExp, replace);
+        serialnumber = serialnumber.replace(regExp, replace);
+
+        tomlFileName = "oeminfo_" + Manufacturer + "_" + productname + "_" + version + "_" + serialnumber;
+        tomlFileName = tomlFileName.trimmed().toLower();
+        tomlFileName = tomlFileName.remove(" ") + ".toml";
+        return tomlFileName;
+    }
+    return QString();
+}
+
+bool CmdTool::parseOemTomlInfo(const QString filename)
+{
+    bool tomlFileRead = false;
+    bool tomlPars = false;
+    QString info = QString();
+
+    if (filename.isEmpty()) {
+        qInfo() << "Toml File name  is null " ;
+        return tomlFileRead;
+    }
+    qInfo() << "Toml File name  is: /etc/deepin/hardware/" << filename;
+
+    QString curPathFile =  "/etc/deepin/hardware/" + filename;
+    if (QFile::exists(curPathFile)) {
+        QFile file(curPathFile);
+        if (file.open(QIODevice::ReadOnly)) {
+            info = file.readAll().data();
+            tomlFileRead = true;
+            file.close();
+        }
+    }
+    if (!tomlFileRead) {
+        curPathFile = "/etc/deepin/hardware/oeminfodebug.toml"; //方便调试，并不开放给用户用
+        QFile file(curPathFile);
+        if (file.open(QIODevice::ReadOnly)) {
+            info = file.readAll().data();
+            tomlFileRead = true;
+            file.close();
+        }
+    }
+
+    if (!tomlFileRead)
+        return tomlFileRead;
+    if (info.isEmpty())
+        return false;
+    QStringList lines = info.split("\n");
+    QRegExp regClass("\\s*(\\[)([.\\w\\s]*)(\\])\\s*#*.*");//正则表达式提取“[XXX]”,XXX为任意字符串。  并去掉[[xxxx]]
+//    QRegExp regKeyValue("\\s*([a-zA-Z0-9_-]+)=\"(.*)\".*");       //裸键只能存在字母、数字、下划线和破折号（a-zA-Z0-9_-）
+//    QRegExp regValue("\\s*\"(.*)\".*");
+    QString classkey;
+    QStringList deviceClassesList;
+    QStringList ValueKeyList;
+    QStringList wordlst;
+    QMap<QString, QString> itemMap;
+    foreach (const QString &line, lines) {
+        if (line.trimmed().startsWith("#"))  // # 开头为注释  不取
+            continue;
+        else if (regClass.exactMatch(line)) {  //[xxx]
+            if (itemMap.count() > 0) {
+                addMapInfo("toml" + classkey, itemMap);
+                tomlPars = true;
+            }
+
+            classkey = regClass.cap(2).split('.').first();
+            itemMap.clear();
+            ValueKeyList.clear();
+            deviceClassesList.append(regClass.cap(2));
+//        } else if (regKeyValue.exactMatch(line)) {  //键值对=
+        } else if (line.contains("=")) {
+            wordlst = line.split("=");
+            if (2 == wordlst.size()) {
+
+                QString key = wordlst[0].remove('"').trimmed();
+                QString valuetmp = wordlst[1];
+                QStringList valuelst;
+                QString value;
+                if (valuetmp.contains("#"))         {
+                    valuelst = valuetmp.split("#");
+                    value = valuelst[0].remove('\"').trimmed();
+                } else
+                    value = valuetmp.remove('\"').trimmed();
+
+                itemMap.insert(key, value);
+                ValueKeyList.append(key);
+            }
+        }
+    }
+    return tomlPars;
+}
 
 void CmdTool::loadLshwInfo(const QString &debugFile)
 {
@@ -196,6 +324,15 @@ void CmdTool::loadLshwInfo(const QString &debugFile)
             addMapInfo("lshw_cdrom", mapInfo);
         }
     }
+    if (!m_cmdInfo.contains("lshw_memory")) {     // 内存信息
+        foreach (const QString &item, items) {
+            if (item.startsWith("memory")) {
+                QMap<QString, QString> mapInfo;
+                getMapInfoFromLshw(item, mapInfo);
+                addMapInfo("lshw_memory", mapInfo);
+            }
+        }
+    }
 }
 
 void CmdTool::loadLsblkInfo(const QString &debugfile)
@@ -349,10 +486,13 @@ void CmdTool::loadBluetoothCtlInfo(QMap<QString, QString> &mapInfo)
         addMapInfo("hciconfig", mapInfo);
         return;
     }
-    QString deviceInfo;
+    QProcess process;
+    process.start("bluetoothctl show " + mapInfo["BD Address"]);
+    process.waitForFinished(2000);
+    QString deviceInfo = process.readAllStandardOutput();
 
     // 读取文件信息
-    if (!getDeviceInfoFromCmd(deviceInfo, "bluetoothctl show " + mapInfo["BD Address"])) {
+    if (deviceInfo.isEmpty()) {
         addMapInfo("hciconfig", mapInfo);
         return;
     }
@@ -501,6 +641,11 @@ void CmdTool::loadDmidecodeInfo(const QString &key, const QString &debugfile)
             continue;
         QMap<QString, QString> mapInfo;
         getMapInfoFromDmidecode(item, mapInfo);
+        if (("dmidecode1" == key) && (mapInfo.size() > 0)) {
+            QString filename = loadOemTomlFileName(mapInfo);
+            parseOemTomlInfo(filename);
+        }
+
         // 过滤空cpu卡槽信息
         if ("dmidecode4" == key && mapInfo.find("ID") == mapInfo.end())
             continue;
@@ -1060,6 +1205,19 @@ void CmdTool::getMapInfoFromHwinfo(const QString &info, QMap<QString, QString> &
         }
     }
 
+    if (mapInfo.contains("VID_PID") && !mapInfo["VID_PID"].isEmpty() && (mapInfo.contains("SysFS ID") || mapInfo.contains("SysFS Device Link"))) {
+        QCryptographicHash Hash(QCryptographicHash::Md5);
+        QByteArray buf;
+        buf.append(mapInfo[tmpkey]);
+        if (mapInfo.contains("SysFS Device Link") && !mapInfo["SysFS Device Link"].isEmpty()) {
+            buf.append(mapInfo["SysFS Device Link"]);
+        } else {
+            buf.append(mapInfo["SysFS ID"]);
+        }
+        Hash.addData(buf);
+        mapInfo["Unique ID"] = QString::fromStdString(Hash.result().toBase64().toStdString());
+    }
+
     if (mapInfo.find("Module Alias") != mapInfo.end())
         mapInfo["Module Alias"].replace(QRegExp("[0-9a-zA-Z]{10}$"), "");
 
@@ -1321,6 +1479,5 @@ bool CmdTool::getCatDeviceInfo(QString &deviceInfo, const QString &debugFile)
 
     deviceInfo = inputDeviceFile.readAll();
     inputDeviceFile.close();
-
     return true;
 }
