@@ -1,24 +1,7 @@
-/*
-* Copyright (C) 2019 ~ 2020 Uniontech Software Technology Co.,Ltd.
-*
-* Author:     Jun.Liu <liujuna@uniontech.com>
-*
-* Maintainer: XiaoMei.Ji <jixiaomei@uniontech.com>
-* Maintainer: Jun.Liu <liujuna@uniontech.com>
-*
-* This program is free software: you can redistribute it and/or modify
-* it under the terms of the GNU General Public License as published by
-* the Free Software Foundation, either version 3 of the License, or
-* any later version.
-*
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-* GNU General Public License for more details.
-*
-* You should have received a copy of the GNU General Public License
-* along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*/
+// Copyright (C) 2019 ~ 2020 Uniontech Software Technology Co.,Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #ifndef CMDTOOL_H
 #define CMDTOOL_H
@@ -69,6 +52,17 @@ public:
      */
     QMap<QString, QList<QMap<QString, QString> > > &cmdInfo();
 
+
+    /**
+     * @brief loadOemTomlFileName: 加载厂商适配信息
+     */
+    QString loadOemTomlFileName(const QMap<QString, QString> &mapInfo);
+
+        /**
+     * @brief parseOemTomlInfo: 解析并加载厂商适配信息
+     */
+    bool parseOemTomlInfo(const QString filename);
+
 private:
 
     /**
@@ -247,8 +241,6 @@ private:
          */
     void loadNvidiaSettingInfo(const QString &key, const QString &debugfile);
 
-private:
-
     /**
      * @brief getMapInfoFromCmd:将通过命令获取的信息字符串，转化为map形式
      * @param info:命令获取的信息字符串
