@@ -1,3 +1,7 @@
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 // 项目自身文件
 #include "DeviceFactory.h"
 #include "X86Generator.h"
@@ -37,6 +41,8 @@ DeviceGenerator *DeviceFactory::getDeviceGenerator()
                 generator = new KLVGenerator();
             else if (type == "PGUV")
                 generator = new PanguVGenerator();
+            else if (type == "KLVU")
+                generator = new KLUGenerator();
             else
                 generator = new HWGenerator();
         } else
