@@ -1,3 +1,7 @@
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 // 项目自身文件
 #include "DeviceGenerator.h"
 
@@ -170,8 +174,8 @@ void DeviceGenerator::generatorCpuDevice()
 
     // set cpu number
     QSet<QString> allCPUS;
-    for (auto dd4:dmidecode4) {
-        if(dd4.contains("Socket Designation"))
+    for (auto dd4 : dmidecode4) {
+        if (dd4.contains("Socket Designation"))
             allCPUS.insert(dd4["Socket Designation"]);
     }
     DeviceManager::instance()->setCpuNum(allCPUS.isEmpty() ? dmidecode4.size() : allCPUS.size());
@@ -235,9 +239,9 @@ void DeviceGenerator::generatorNetworkDevice()
     const QList<QMap<QString, QString>> &lstHWInfo = DeviceManager::instance()->cmdInfo("hwinfo_network");
     for (QList<QMap<QString, QString> >::const_iterator it = lstHWInfo.begin(); it != lstHWInfo.end(); ++it) {
         // Hardware Class 类型为 network interface
-        if ("network" == (*it)["Hardware Class"]) {
-            continue;
-        }
+//        if ("network" == (*it)["Hardware Class"]) {  //去掉， 并与service端同步"hwinfo --network"改为 "hwinfo --netcard"获取网卡信息
+//            continue;
+//        }
 
         // 先判断是否是有效网卡信息
         // 符合两种情况中的一种 1. "HW Address" 和 "Permanent HW Address" 都必须有  2. 有 "unique_id"
@@ -290,8 +294,6 @@ void DeviceGenerator::generatorAudioDevice()
     // getAudioChipInfoFromDmesg();  //将两个设备芯片显示为一个，该功能代码逻辑错误  被 getAudioInfoFrom_sysFS 取代
     getAudioInfoFromLshw();
     getAudioInfoFrom_sysFS();
-    // getAudioInfoFromCatInput();
-    
 }
 
 void DeviceGenerator::generatorBluetoothDevice()
@@ -563,9 +565,6 @@ void DeviceGenerator::getDiskInfoFromSmartCtl()
     const QList<QMap<QString, QString>> &lstMap = DeviceManager::instance()->cmdInfo("smart");
     QList<QMap<QString, QString> >::const_iterator it = lstMap.begin();
     for (; it != lstMap.end(); ++it) {
-        if ((*it).size() < 5)
-            continue;
-
         DeviceManager::instance()->setStorageInfoFromSmartctl((*it)["ln"], *it);
     }
 }
@@ -619,11 +618,10 @@ void DeviceGenerator::getGpuSizeFromDmesg()
     if (lstMap.size() > 0 && lstMap[0].size() > 0)
         for (QMap<QString, QString> curMap : lstMap) {
             DeviceManager::instance()->setGpuSizeFromDmesg(curMap);
-        }
-    else {
+        } else {
         // dmesg无法获取显存信息时从nvidia-settings获取
         const QList<QMap<QString, QString>> &nvidiaMap = DeviceManager::instance()->cmdInfo("nvidia");
-        if (nvidiaMap.size() > 0 && nvidiaMap[0].size() > 0){
+        if (nvidiaMap.size() > 0 && nvidiaMap[0].size() > 0) {
             for (QMap<QString, QString> curMap : nvidiaMap) {
                 DeviceManager::instance()->setGpuSizeFromDmesg(curMap);
             }
@@ -692,19 +690,21 @@ void DeviceGenerator::getAudioInfoFrom_sysFS()
     QMap<QString, QString> mapInfo;
     QString path;
 
-    for(int i=0; i<5;i++){
+    for (int i = 0; i < 5; i++) {
         mapInfo.clear();
         DeviceAudio *device = new DeviceAudio();
-        bool getcard = device->setInfoFrom_sysFS(mapInfo,i);
-        if(getcard){
+        bool getcard = device->setInfoFrom_sysFS(mapInfo, i);
+        if (getcard) {
             path = mapInfo["SysFS ID"];
             DeviceAudio *tmpdevice = dynamic_cast<DeviceAudio *>(DeviceManager::instance()->getAudioDevice(path));
-            if (!tmpdevice){  // 没有该设备 说加新的
+            if (!tmpdevice) { // 没有该设备 说加新的
                 DeviceManager::instance()->addAudioDevice(device);
-            } else{  //找到有就 加芯片等信息
+            } else { //找到有就 加芯片等信息
                 QString chip = mapInfo["chip"];
                 // DeviceManager::instance()->setAudioChipFromDmesg(chip);
                 tmpdevice->setAudioChipFromDmesg(chip);
+                delete device;
+                device = nullptr;
             }
         }
     }
@@ -721,7 +721,7 @@ void DeviceGenerator::getAudioInfoFromLshw()
 
         DeviceManager::instance()->setAudioInfoFromLshw(*it);
     }
-     DeviceManager::instance()->deleteDisableDuplicate_AudioDevice();  //bug 150331  禁用显卡音频，重启后音频信息异常增多
+    DeviceManager::instance()->deleteDisableDuplicate_AudioDevice();  //bug 150331  禁用显卡音频，重启后音频信息异常增多
 }
 
 void DeviceGenerator::getAudioInfoFromCatInput()
@@ -792,6 +792,23 @@ void DeviceGenerator::getBlueToothInfoFromHwinfo()
             device->setInfoFromHwinfo(*it);
             DeviceManager::instance()->addBluetoothDevice(device);
             addBusIDFromHwinfo((*it)["SysFS BusID"]);
+        } else if (!it->contains("Driver") && it->contains("Driver Status") && (*it)["Driver Status"].contains("is")) {
+            QStringList driverStatus = (*it)["Driver Status"].split("is");
+            if (!driverStatus.isEmpty() && driverStatus.first().contains("btusb")) {
+                // 判断重复设备数据
+                QString unique_id = uniqueID(*it);
+                DeviceBluetooth *device = dynamic_cast<DeviceBluetooth *>(DeviceManager::instance()->getBluetoothDevice(unique_id));
+                if (device) {
+                    device->setEnableValue(false);
+                    device->setInfoFromHwinfo(*it);
+                    continue;
+                }
+
+                device = new DeviceBluetooth();
+                device->setInfoFromHwinfo(*it);
+                DeviceManager::instance()->addBluetoothDevice(device);
+                addBusIDFromHwinfo((*it)["SysFS BusID"]);
+            }
         }
     }
 }
@@ -1023,11 +1040,11 @@ void DeviceGenerator::getOthersInfoFromHwinfo()
     for (; it != lstMap.end(); ++it) {
         if ((*it).size() < 3)
             continue;
-/*  bug 141439 不可见功能设计需要再次思考*/
-        if (  (*it).find("Device") != (*it).end() &&
-             ((*it)["Device"].contains("fingerprint", Qt::CaseInsensitive)  ||  
-              (*it)["Device"].contains("MOH", Qt::CaseInsensitive)
-             )) { 
+        /*  bug 141439 不可见功能设计需要再次思考*/
+        if ((*it).find("Device") != (*it).end() &&
+                ((*it)["Device"].contains("fingerprint", Qt::CaseInsensitive)  ||
+                 (*it)["Device"].contains("MOH", Qt::CaseInsensitive)
+                )) {
             DeviceOthers *device = new DeviceOthers();
             device->setForcedDisplay(true);
             device->setInfoFromHwinfo(*it);
@@ -1147,6 +1164,8 @@ QString DeviceGenerator::uniqueID(const QMap<QString, QString> &mapInfo)
 {
     if (mapInfo.find("unique_id") != mapInfo.end()) {
         return mapInfo["unique_id"];
+    } else if (mapInfo.find("Unique ID") != mapInfo.end()) {
+        return mapInfo["Unique ID"];
     } else if (mapInfo.find("Permanent HW Address") != mapInfo.end()) {
         return mapInfo["Permanent HW Address"];
     } else if (mapInfo.find("Serial ID") != mapInfo.end()) {
@@ -1155,3 +1174,8 @@ QString DeviceGenerator::uniqueID(const QMap<QString, QString> &mapInfo)
     return "";
 }
 
+void DeviceGenerator::generatorInfoFromToml(DeviceType deviceType)
+{
+    DeviceManager::instance()->tomlDeviceSet(deviceType);
+}
+
