@@ -1,3 +1,7 @@
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 #include "LoadInfoThread.h"
 #include "GetInfoPool.h"
 #include "GenerateDevicePool.h"
@@ -6,9 +10,11 @@
 
 #include <QDebug>
 #include <QDateTime>
+#include <QTimer>
 
 #include<malloc.h>
 
+static bool firstLoadFlag = true;
 LoadInfoThread::LoadInfoThread()
     : mp_ReadFilePool()
     , mp_GenerateDevicePool()
@@ -56,7 +62,7 @@ void LoadInfoThread::run()
                     break;
                 usleep(100);
             }
-            if ((++readNum) > 2) {
+            if ((++readNum) > 3) {
                 if (m_FinishedReadFilePool && !readDataFlag) {
                     mp_ReadFilePool.getAllInfo();
                     mp_ReadFilePool.waitForDone(-1);
@@ -86,6 +92,14 @@ void LoadInfoThread::run()
 void LoadInfoThread::slotFinishedReadFilePool(const QString &)
 {
     m_FinishedReadFilePool = true;
+    // 首次加载刷新
+    if (firstLoadFlag) {
+        firstLoadFlag = false;
+        DBusInterface::getInstance()->refreshInfo();
+        QTimer::singleShot(500, this, [ = ]() {
+            start();
+        });
+    }
 }
 
 void LoadInfoThread::setFramework(const QString &arch)
