@@ -1,3 +1,7 @@
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 #include "PageDriverManager.h"
 #include "drivertableview.h"
 #include "DetectedStatusWidget.h"
@@ -72,6 +76,11 @@ PageDriverManager::PageDriverManager(DWidget *parent)
 
 PageDriverManager::~PageDriverManager()
 {
+    // 扫描驱动时关闭线程
+    if (mp_scanner->isRunning()) {
+        mp_scanner->terminate();
+        mp_scanner->wait();
+    }
     DELETE_PTR(mp_ViewNotInstall);
     DELETE_PTR(mp_ViewCanUpdate);
     DELETE_PTR(mp_AllDriverIsNew);
@@ -104,8 +113,15 @@ bool PageDriverManager::isInstalling()
     return mp_CurDriverInfo != nullptr;
 }
 
+bool PageDriverManager::isScanning()
+{
+    return m_Scanning;
+}
+
 void PageDriverManager::scanDriverInfo()
 {
+    if (m_Scanning)
+        return;
     m_IsFirstScan = false;
     m_Scanning = true;
     // 如果在安装过程中则不扫描
@@ -310,6 +326,7 @@ void PageDriverManager::slotScanFinished(ScanResult sr)
 
     // 扫描结束，可以继续扫描
     m_Scanning = false;
+    emit scanFinished();
 }
 
 void PageDriverManager::slotUndoInstall()
