@@ -1,3 +1,7 @@
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 #ifndef PAGEDRIVERMANAGER_H
 #define PAGEDRIVERMANAGER_H
 
@@ -47,6 +51,12 @@ public:
      */
     bool isInstalling();
 
+    /**
+     * @brief isScanning：判断当前是否扫描
+     * @return
+     */
+    bool isScanning();
+
 public slots:
 
     /**
@@ -109,6 +119,7 @@ private slots:
 
 signals:
     void startScanning();
+    void scanFinished();
 
 private:
     /**
