@@ -1,3 +1,7 @@
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 // 项目自身文件
 #include "PageListView.h"
 #include "DeviceListView.h"
@@ -72,6 +76,16 @@ QString PageListView::currentType()
     return m_CurType;
 }
 
+void PageListView::clear()
+{
+    if (!mp_ListView) {
+        return;
+    }
+
+    // 更新之前先清理
+    mp_ListView->clearItem();
+}
+
 void PageListView::paintEvent(QPaintEvent *event)
 {
     // 让背景色适合主题颜色
